`timescale 1ns / 1ps
//////////////////////////////////////////////////////////////////////////////////////////
// Company: Digilent RO
// Engineer: Mircea Dabacan
// 
// Create Date:    14:06:46 03/01/2008 
// Module Name:    VgaRefComp
// Project Name: 	 PmodPS2_Demo
// Target Devices: Nexys3
// Tool versions:  ISE 14.2 
// Description: This is the structural VHDL code of the 
//              Digilent VGA Reference Component.
//              It instantiates three components:
//                - vga_selector
//                - vga_controller_640_60
//                - vga_controller_800_60
//
// Revision: 
// Revision 0.01 - File Created
// Revision 1.00 - Converted from VHDL to Verilog (Josh Sackos)
//////////////////////////////////////////////////////////////////////////////////////////

// =======================================================================================
// 										  Define Module
// =======================================================================================
module VgaRefComp(
		CLK_25MHz,
		CLK_40MHz,
		RESOLUTION,
		RST,
		BLANK,
		HCOUNT,
		HS,
		VCOUNT,
		VS
);

// =======================================================================================
// 										Port Declarations
// =======================================================================================

			input         CLK_25MHz;
			input         CLK_40MHz;
			input         RESOLUTION;
			input         RST;
			output        BLANK;
			output [10:0] HCOUNT;
			output        HS;
			output [10:0] VCOUNT;
			output        VS;

// =======================================================================================
// 							  Parameters, Registers, and Wires
// =======================================================================================   

			wire          bitBlank800_60;
			wire          bitHS_800_60;
			wire          bitHS_640_60;
			wire          bitVS_640_60;
			wire          bitBlank640_60;
			wire          bitVS_800_60;
			wire [10:0]   vecHcount_640_60;
			wire [10:0]   vecVcount_640_60;
			wire [10:0]   bitHcount_800_60;
			wire [10:0]   vecVcount_800_60;
   
// =======================================================================================
// 							  		   Implementation
// =======================================================================================

			//--------------------------------------
			//	  				VGA Selector
			//--------------------------------------
			vga_selector VgaSelectorInst(
						.blank_640_60(bitBlank640_60),
						.blank_800_60(bitBlank800_60),
						.hcount_640_60(vecHcount_640_60[10:0]),
						.hcount_800_60(bitHcount_800_60[10:0]),
						.HS_640_60(bitHS_640_60),
						.HS_800_60(bitHS_800_60),
						.resolution(RESOLUTION),
						.vcount_640_60(vecVcount_640_60[10:0]),
						.vcount_800_60(vecVcount_800_60[10:0]),
						.VS_640_60(bitVS_640_60),
						.VS_800_60(bitVS_800_60),
						.blank(BLANK),
						.hcount(HCOUNT[10:0]),
						.hs(HS),
						.vcount(VCOUNT[10:0]),
						.vs(VS)
			);

			//--------------------------------------
			//	  			For 640 Resolution
			//--------------------------------------
			vga_controller_640_60 VgaCtrl640_60(
						.pixel_clk(CLK_25MHz),
						.rst(RST),
						.blank(bitBlank640_60),
						.hcount(vecHcount_640_60[10:0]),
						.HS(bitHS_640_60),
						.vcount(vecVcount_640_60[10:0]),
						.VS(bitVS_640_60)
			);

			//--------------------------------------
			//	  		  For 800 Resolution
			//--------------------------------------
			vga_controller_800_60 VgaCtrl800_60(
						.pixel_clk(CLK_40MHz),
						.rst(RST),
						.blank(bitBlank800_60),
						.hcount(bitHcount_800_60[10:0]),
						.HS(bitHS_800_60),
						.vcount(vecVcount_800_60[10:0]),
						.VS(bitVS_800_60)
			);
   
endmodule
